@@ -33,9 +33,10 @@
 #  define KASTENCONTROLLERS_DEPRECATED_NO_EXPORT KASTENCONTROLLERS_NO_EXPORT KASTENCONTROLLERS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KASTENCONTROLLERS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KASTENCONTROLLERS_NO_DEPRECATED
+#    define KASTENCONTROLLERS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
