@@ -33,9 +33,10 @@
 #  define KASTENCORE_DEPRECATED_NO_EXPORT KASTENCORE_NO_EXPORT KASTENCORE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KASTENCORE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KASTENCORE_NO_DEPRECATED
+#    define KASTENCORE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
